@@ -3,7 +3,7 @@
 =begin
   po2ul - generate a sorted list of unicode codepoint used in po files.
 
-  Copyright (C) 2005  Hidetaka Iwai  <tyuyu@debian.or.jp>
+  Copyright (C) 2005-2007  Hidetaka Iwai  <tyuyu@debian.or.jp>
   
   Depends: ruby (>= 1.8), libgettext-ruby1.8
 =end
@@ -29,12 +29,20 @@ end
 list = []
 if ARGV.size == 0
   ret = parse(STDIN.read)
-  list += Iconv.conv("UCS-4BE", ret["encoding"], ret["msgstr"]).unpack("N*")
+  begin
+    list += Iconv.conv("UCS-4BE", ret["encoding"], ret["msgstr"]).unpack("N*")
+  rescue
+    # skip untranslated po file
+  end
 else
   while filename = ARGV.shift
     next unless (st = File.stat(filename)) && st.file? && st.readable?
     ret = parse(File.open(filename).read)
-    list += Iconv.conv("UCS-4BE", ret["encoding"], ret["msgstr"]).unpack("N*")
+    begin
+      list += Iconv.conv("UCS-4BE", ret["encoding"], ret["msgstr"]).unpack("N*")
+    rescue
+      # skip untranslated po file
+    end
   end
 end
 
